@@ -1,7 +1,8 @@
-"""Backend(s) for web annotation.
+"""
+Backend for web annotation.
 
 @copyright: (c) 2006-2010 Open Knowledge Foundation
 """
-__version__ = '0.4'
+__version__ = '0.4.1'
 __license__ = 'MIT'
 __author__ = 'Rufus Pollock (Open Knowledge Foundation)'
