@@ -127,7 +127,10 @@ class AnnotatorStore(object):
         return self._json(result)
 
     def create(self):
-        params = json.loads(dict(self.request.params).keys()[0])
+        if 'json' in self.request.params:
+            params = json.loads(self.request.params['json'])
+        else:
+            params = dict(self.request.params)
         if isinstance(params, list):
             for objdict in params:
                 anno = model.Annotation.from_dict(objdict)
@@ -149,12 +152,12 @@ class AnnotatorStore(object):
         if not anno:
             return self._404()
 
-        params = json.loads(self.request.params.keys()[0])
+        if 'json' in self.request.params:
+            params = json.loads(self.request.params['json'])
+        else:
+            params = dict(self.request.params)
 
         params['id'] = id
-        # set by db not client ...
-        if 'created' in params:
-            del params['created']
         anno = model.Annotation.from_dict(params)
         anno.save_changes()
 
